/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.renderkit.html.standard.standard.tag;

import org.apache.myfaces.tobago.component.Attributes;
import org.apache.myfaces.tobago.internal.component.AbstractUICommand;
import org.apache.myfaces.tobago.renderkit.css.BootstrapClass;
import org.apache.myfaces.tobago.renderkit.css.CssItem;
import org.apache.myfaces.tobago.renderkit.html.HtmlAttributes;
import org.apache.myfaces.tobago.renderkit.html.HtmlButtonTypes;
import org.apache.myfaces.tobago.renderkit.html.HtmlElements;
import org.apache.myfaces.tobago.util.ComponentUtils;
import org.apache.myfaces.tobago.webapp.TobagoResponseWriter;

import javax.faces.context.FacesContext;
import java.io.IOException;
import java.util.List;

public class ButtonRenderer extends CommandRendererBase {

  @Override
  protected void encodeBeginElement(final FacesContext facesContext, final AbstractUICommand command)
      throws IOException {
    final TobagoResponseWriter writer = getResponseWriter(facesContext);

    writer.startElement(HtmlElements.BUTTON);
    writer.writeAttribute(HtmlAttributes.TYPE, HtmlButtonTypes.BUTTON);
  }

  @Override
  protected void encodeEndElement(final FacesContext facesContext, final AbstractUICommand command)
      throws IOException {
    final TobagoResponseWriter writer = getResponseWriter(facesContext);

    writer.endElement(HtmlElements.BUTTON);
  }

  @Override
  protected void encodeBeginOuter(final FacesContext facesContext, final AbstractUICommand command)
      throws IOException {
    final TobagoResponseWriter writer = getResponseWriter(facesContext);

//    if (isMarked(facesContext, MARKER)) { // this is only needed, if button has a sub-menu (dropdown)
      writer.startElement(HtmlElements.SPAN);
      writer.writeClassAttribute(BootstrapClass.BTN_GROUP);
//    }
  }

  @Override
  protected void encodeEndOuter(final FacesContext facesContext, final AbstractUICommand command)
      throws IOException {
    final TobagoResponseWriter writer = getResponseWriter(facesContext);

//    if (isMarked(facesContext, MARKER)) {
      writer.endElement(HtmlElements.SPAN);
//    }
  }

  @Override
  protected void addCssItems(
      final FacesContext facesContext, final AbstractUICommand command, final List<CssItem> collected) {

    final boolean defaultCommand = ComponentUtils.getBooleanAttribute(command, Attributes.defaultCommand);

    collected.add(BootstrapClass.BTN);
    collected.add(defaultCommand ? BootstrapClass.BTN_PRIMARY : BootstrapClass.BTN_SECONDARY);
// todo    collected.add(insideToolbar ? BootstrapClass.NAVBAR_BTN : null);
  }

}
